==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebMaskInputBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
/**
 * @hidden
 */
export let WebMaskInputBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMaskInputBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebMaskInputBaseDescriptionMetadata.a == null) {
                WebMaskInputBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMaskInputBaseDescriptionMetadata.c(WebMaskInputBaseDescriptionMetadata.a);
            }
            if (a.j(WebMaskInputBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(WebMaskInputBaseDescriptionMetadata.a);
        }
        static c(a) {
            WebInputBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:MaskInputBase");
            a.item("Prompt", "String");
            a.item("Invalid", "Boolean");
        }
        static d(a) {
            WebMaskInputBaseDescriptionMetadata.b(a);
            a.z("WebMaskInputBase", WebMaskInputBaseDescriptionMetadata.a);
        }
    }
    WebMaskInputBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMaskInputBaseDescriptionMetadata, 'WebMaskInputBaseDescriptionMetadata');
    WebMaskInputBaseDescriptionMetadata.a = null;
    return WebMaskInputBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebMaskInputBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
/**
 * @hidden
 */
export let WebMaskInputBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMaskInputBaseDescriptionMetadata extends Base {
        static b(a) {
            if (WebMaskInputBaseDescriptionMetadata.a == null) {
                WebMaskInputBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMaskInputBaseDescriptionMetadata.c(WebMaskInputBaseDescriptionMetadata.a);
            }
            if (a.k(WebMaskInputBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebMaskInputBaseDescriptionMetadata.a);
        }
        static c(a) {
            WebInputBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:MaskInputBase");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Prompt", "String");
            a.item("Invalid", "Boolean");
        }
        static d(a) {
            WebMaskInputBaseDescriptionMetadata.b(a);
            a.ab("WebMaskInputBase", WebMaskInputBaseDescriptionMetadata.a);
        }
    }
    WebMaskInputBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMaskInputBaseDescriptionMetadata, 'WebMaskInputBaseDescriptionMetadata');
    WebMaskInputBaseDescriptionMetadata.a = null;
    return WebMaskInputBaseDescriptionMetadata;
})();
